@@ -18,7 +18,6 @@
 
 import os
 import pytest
-import shutil
 import subprocess
 
 from path import path
@@ -72,6 +71,10 @@ redisdb = factories.redisdb('redis_proc')
 postgresql_proc = factories.postgresql_proc()
 postgresql = factories.postgresql('postgresql_proc')
 
+mysql_proc = factories.mysql_proc()
+mysqldb = factories.mysqldb('mysql_proc', scope='function')
+mysqldb_session = factories.mysqldb('mysql_proc')
+
 
 @pytest.fixture(scope='session')
 def mongo_proc(request):
@@ -252,143 +255,3 @@ def rabbitmq(rabbitmq_proc, request):
         print "Be sure that you're connecting rabbitmq-server >= 2.8.4"
 
     return rabbit_connection
-
-
-def remove_mysql_directory(config):
-    """
-    Checks mysql directory. Recursively delete a directory tree if exist.
-
-    :param pymlconf.ConfigManager config: config
-
-    """
-    if os.path.isdir(config.mysql.datadir):
-        shutil.rmtree(config.mysql.datadir)
-
-
-def init_mysql_directory(config):
-    """
-    #. Remove mysql directory if exist.
-    #. `Initialize MySQL data directory
-        <https://dev.mysql.com/doc/refman/5.0/en/mysql-install-db.html>`_
-
-    :param pymlconf.ConfigManager config: config
-
-    """
-    remove_mysql_directory(config)
-    init_directory = (
-        config.mysql.mysql_init,
-        '--user=%s' % os.getenv('USER'),
-        '--datadir=%s' % config.mysql.datadir,
-    )
-    subprocess.check_output(' '.join(init_directory), shell=True)
-
-
-@pytest.fixture(scope='session')
-def mysql_proc(request):
-    """
-    #. Get config.
-    #. Initialize MySQL data directory
-    #. `Start a mysqld server
-        <https://dev.mysql.com/doc/refman/5.0/en/mysqld-safe.html>`_
-    #. Stop server and remove directory after tests.
-        `See <https://dev.mysql.com/doc/refman/5.6/en/mysqladmin.html>`_
-
-    :param FixtureRequest request: fixture request object
-    :rtype: summon_process.executors.tcp_coordinated_executor.TCPCoordinatedExecutor # noqa
-    :returns: tcp executor
-
-    """
-    config = get_config(request)
-    init_mysql_directory(config)
-
-    mysql_executor = TCPCoordinatedExecutor(
-        '''
-            {mysql_server} --datadir={datadir} --pid-file={pidfile}
-            --port={port} --socket={socket} --log-error={logfile}
-            --skip-syslog
-        '''.format(
-        mysql_server=config.mysql.mysql_server,
-        datadir=config.mysql.datadir,
-        pidfile=config.mysql.pidfile,
-        port=config.mysql.port,
-        socket=config.mysql.socket,
-        logfile=config.mysql.logfile,
-    ),
-        host=config.mysql.host,
-        port=config.mysql.port,
-    )
-    mysql_executor.start()
-
-    def shutdown_server():
-        return (
-            config.mysql.mysql_admin,
-            '--socket=%s' % config.mysql.socket,
-            '--user=%s' % config.mysql.user,
-            'shutdown'
-        )
-
-    def stop_server_and_remove_directory():
-        subprocess.check_output(' '.join(shutdown_server()), shell=True)
-        mysql_executor.stop()
-        remove_mysql_directory(config)
-
-    request.addfinalizer(stop_server_and_remove_directory)
-
-    return mysql_executor
-
-
-def mysqldb_fixture_factory(scope='session'):
-    """
-    Factory. Create connection to mysql. If you want you can give a scope,
-    default is 'session'.
-
-    :param str scope: scope (session, function, module, etc.)
-    :rtype: func
-    :returns: function ``mysqldb_fixture`` with suit scope
-    """
-
-    @pytest.fixture(scope)
-    def mysqldb_fixture(request, mysql_proc):
-        """
-        #. Get config.
-        #. Try to import MySQLdb package.
-        #. Connect to mysql server.
-        #. Create database.
-        #. Use proper database.
-        #. Drop database after tests.
-
-        :param FixtureRequest request: fixture request object
-        :param TCPCoordinatedExecutor mysql_proc: tcp executor
-        :rtype: MySQLdb.connections.Connection
-        :returns: connection to database
-        """
-
-        config = get_config(request)
-
-        MySQLdb, config = try_import(
-            'MySQLdb', request, pypi_package='MySQL-python'
-        )
-
-        mysql_conn = MySQLdb.connect(
-            host=config.mysql.host,
-            unix_socket=config.mysql.socket,
-            user=config.mysql.user,
-            passwd=config.mysql.password,
-        )
-
-        mysql_conn.query('CREATE DATABASE %s' % config.mysql.db)
-        mysql_conn.query('USE %s' % config.mysql.db)
-
-        def drop_database():
-            mysql_conn.query('DROP DATABASE IF EXISTS %s' % config.mysql.db)
-            mysql_conn.close()
-
-        request.addfinalizer(drop_database)
-
-        return mysql_conn
-
-    return mysqldb_fixture
-
-
-mysqldb_session = mysqldb_fixture_factory()
-mysqldb = mysqldb_fixture_factory(scope='function')
